pub struct CompiledFunctionMetadata {
pub event_sites: Vec<EventSiteMetadata>,
}Expand description
Runtime metadata for all observable sites in one compiled function.
Fields
event_sites: Vec<EventSiteMetadata>Trait Implementations
Sourceimpl Clone for CompiledFunctionMetadata
impl Clone for CompiledFunctionMetadata
Sourcefn clone(&self) -> CompiledFunctionMetadata
fn clone(&self) -> CompiledFunctionMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledFunctionMetadata
impl Debug for CompiledFunctionMetadata
Sourceimpl Default for CompiledFunctionMetadata
impl Default for CompiledFunctionMetadata
Sourcefn default() -> CompiledFunctionMetadata
fn default() -> CompiledFunctionMetadata
Returns the “default value” for a type. Read more
impl Eq for CompiledFunctionMetadata
Sourceimpl PartialEq for CompiledFunctionMetadata
impl PartialEq for CompiledFunctionMetadata
Sourcefn eq(&self, other: &CompiledFunctionMetadata) -> bool
fn eq(&self, other: &CompiledFunctionMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompiledFunctionMetadata